## Script developed by CSDambros in February 16th 2023 ###

# Using unmarked to estimate occupancy in R

# First step:
# Go to https://docs.google.com/spreadsheets/d/1sm3_Fvp2nwIIAcBEDzYRexiBCkZPnLZx3Ebl37HENHo and use the three sheets (occ, detCovs and siteCovs) as templates for your data.

# Second step:
# Go to https://cdfviv-cristian-dambros.shinyapps.io/OccupancyDataOrganizer/ and upload the three files with species occurrence data (detections only, no zeroes or missing data needed), replicate data, and site data. Download the formated data as a 3d array. Save the file as array3d.rds

# Third step:
# Import the .rds file to R:
array3d<-readRDS("array3d.rds")

# Fourth step:
# Extract data for species of interest and covariates from object
occurrenceData<-array3d$occ
siteCovs<-array3d$siteCovs
obsCovs<-array3d$obsCovs

# Select first species (change the number to select other species)
occurrenceDataSp1<-occurrenceData[,,1]

# check covariates that can be used as predictors for detection and occupancy
# detection
names(array3d$obsCovs)

# occupacy
names(array3d$siteCovs)


# Fifth step:
# Using unmkared to estimate parameters
library(unmarked)

umk<-unmarkedFrameOccu(y=occurrenceDataSp1,
                       obsCovs = obsCovs,
                       siteCovs = siteCovs)

summary(umk)

# Run occupancy model for one species
occu(~soilDeph+fragmentSize~fragmentSize,umk)

# You can use Multi-Species Occupancy Models to run the model to all species simultaneously